rnalysis.filtering.CountFilter.split\_by\_ref\_table\_attr
============================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: CountFilter.split_by_ref_table_attr
